#!/sbin/sh
#
# @(#)post.sh	1.14  09/11/98 SMI
# Portions Copyright (c) 1996, 1997 Sun Microsystems, Inc.
# All Rights Reserved.
#
# Copyright (c) 1994, 1997 Innosoft International, Inc.
# All Rights Reserved.
#
# post - shell script called by cron to periodically run post
#

#
# we have to hard code the path to the tailor file.
#
#
IMTATAILOR=/etc/opt/SUNWmail/imta/imta_tailor

##################################################################
# give some initial default values to all paths.
##################################################################
IMTAPATH=/opt/SUNWmail/imta
IMTALOGPATH=/var/opt/SUNWmail/imta/log
QUEUEDIR=/var/opt/SUNWmail/imta/queue/

##################################################################
# shell function to get a variable's value
# from tailor file.
#
# Fix: The old way will get value of IMTA_VERSION_LIMIT_PERIOD for
#      IMTA_VERSION_LIMIT by mistake, for example.
##################################################################
getTailorValue() {
 y=`/bin/grep "^$1=" $IMTATAILOR |/bin/awk -F= '{print $2}' | sort | head -1`
 echo $y
}

##################################################################
# shell function to get some values from tailor file.
##################################################################
getValuesFromTailor() {
  IMTAPATH=`getTailorValue IMTA_ROOT`
  IMTALOGPATH=`getTailorValue IMTA_LOG`
  QUEUEDIR=`getTailorValue IMTA_QUEUE`
}

##################################################################
# try to read and reinitialize all the paths from the tailor file
# if it exists.
##################################################################
if test -f $IMTATAILOR; then
  getValuesFromTailor
fi

##################################################################
# real action begins now.
##################################################################

# get and increment the number of times we have run since the last reboot.
#$IMTAPATH/lib/get_count post | read post_count
post_count=`$IMTAPATH/lib/get_count post`



# resynchronize if needed
synch_cache_period=`getTailorValue IMTA_SYNCH_CACHE_PERIOD`
if [ -z "$synch_cache_period" ]
then
  synch_cache_period=3
elif [ $synch_cache_period -lt 1 ]
then
  synch_cache_period=3
fi
if [ `expr $post_count % $synch_cache_period` -eq 0 ]
then
  $IMTAPATH/lib/synch_cache cache -sync
fi

#
# call the post utility to do all the work
# Fix: should synch the cache first before calling the post
#      so the following line moved here.

$IMTAPATH/lib/post

# purge old log file versions.
# if command line specify number of version to keep, that will override
# the IMTA_VERSION_LIMIT in the /etc/opt/SUNWmail/sbin/imta_tailor.
# Also, check if IMTA_VERSION_LIMIT_PERIOD is defined and act accordingly.
version_limit_period=`getTailorValue IMTA_VERSION_LIMIT_PERIOD`
if [ -z "$version_limit_period"  -o  $version_limit_period -lt 1 ]
then
  version_limit_period=1
fi
if [ `expr $post_count % $version_limit_period` -eq 0 ]
then
  if [ $# -gt 1 ]
  then
    $IMTAPATH/lib/purge $*
  else
    version_limit=`getTailorValue IMTA_VERSION_LIMIT`
    if [ -z "$version_limit"  -o  $version_limit -lt 1 ]
    then
      $IMTAPATH/lib/purge $IMTALOGPATH/*.log- $IMTALOGPATH/*.trn- $IMTALOGPATH/*.trc-
    else
      $IMTAPATH/lib/purge -num=$version_limit $IMTALOGPATH/*.log- $IMTALOGPATH/*.trn- $IMTALOGPATH/*.trc-
    fi
  fi
fi

#
# Check for .HELD files and inform postmaster if any
#
cd $QUEUEDIR
queue_list=None

ls */*/*.HELD > /tmp/held 2> /dev/null
status=`echo $?`

if [ $status -eq 0 ]; then
  for queue in `cut -d/ -f1 /tmp/held`; do
    if [ $queue_list = "None" ]; then
        last_queue=$queue
        queue_list=$queue
    else
        if [ $last_queue != $queue ]; then
            queue_list="$queue_list,$queue"
            last_queue=$queue
        fi
    fi
  done
  if [ $queue_list != "None" ]; then
    echo "There are held messages in the following queues- " > /tmp/held_warning
    echo "$queue_list" >> /tmp/held_warning
    echo "Correct the cause for the mail loop and run" >> /tmp/held_warning
    echo "% imta -retry_delivery queue_name" >> /tmp/held_warning
    /opt/SUNWmail/imta/bin/sendmail postmaster < /tmp/held_warning
    rm -f /tmp/held_warning
  fi
fi
rm -f /tmp/held 2> /dev/null

